import 'dart:async';

import 'package:domain/repository/auth_repository.dart';
import 'package:flutter/material.dart';
import 'package:flutter_smart_dialog/flutter_smart_dialog.dart';
import 'package:get/get.dart';
import 'package:plugin_platform/http/http_result.dart';
import 'package:shared/utils/ext_dart.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:shared/utils/util.dart';



import 'change_mobile_state.dart';

class ChangeMobileController extends GetxController {
  final ChangeMobileState state = ChangeMobileState();
  final AuthRepository authRepository = Get.find();

  String? mobilePhoneErrorText; //表单的错误信息展示
  String? codeErrorText;

  String? phone;
  String? code;


  /// 执行手机号码的绑定
  void doChangePhone() {
    mobilePhoneErrorText = null;
    codeErrorText = null;
    update();

    var phoneController = state.formData['phone']!['controller'];
    var codeController = state.formData['code']!['controller'];

    phone = phoneController.text;
    code = codeController.text;

    Log.d('phone:$phone code:$code');

    if (Utils.isEmpty(phone)) {
      mobilePhoneErrorText = "电话号码不能为空";
      update();
    } else if (Utils.isEmpty(code)) {
      codeErrorText = "验证码不能为空";
      update();
    }  else {
      _requestForgetPsd();
    }
  }

  /// 请求接口，普通的密码注册
  void _requestForgetPsd() async {
    // //获取到数据
    // SmartDialog.showLoading();
    // var result = await authRepository.updateMobilePhone(phone, code);
    // SmartDialog.dismiss(status: SmartStatus.loading);
    //
    // //处理数据
    // if (result.isSuccess) {
    //   SmartDialog.showNotify(msg:'修改手机号码成功',notifyType: NotifyType.success);
    //
    //   //发送通知刷新用户详情信息
    //   bus.emit(AppConstant.eventProfile2Refresh, true);
    //
    //   //成功了返回
    //   Get.back();
    // } else {
    //   _handleErrorMessage(result);
    // }
  }

  /// 处理网络请求注册的表单错误
  void _handleErrorMessage(HttpResult<dynamic> result) {
    String? errorMessage = result.errorMsg;
    SmartDialog.showToast(errorMessage ?? '未知错误'.tr);

    Map<String, dynamic>? json = result.getErrorJson();
    handleFormError(json, 'phone', (str) {
      mobilePhoneErrorText = str;
    });
    handleFormError(json, 'sms_verification_code', (str) {
      codeErrorText = str;
    });
  }

  /// 默认的App Dialog
  void showVerifyCodedDialog() {
    //隐藏全部的软键盘与焦点
    _phoneFocusNode?.unfocus();
    _codeFocusNode?.unfocus();

    //校验手机号码不能为空
    phone = state.formData['phone']!['controller'].text;
    if (Utils.isEmpty(phone)) {
      mobilePhoneErrorText = "电话号码不能为空";
      update();
    } else {
      // SmartDialog.show(
      //   usePenetrate: false,
      //   debounce: true,
      //   clickMaskDismiss: false,
      //   onDismiss: () {
      //     //每次取消弹窗都要手动删除弹窗的Controller，不然无法每次弹出都请求接口
      //     Get.delete<VerifyCodeDialogController>();
      //   },
      //   builder: (context) => VerifyCodeDialog(
      //     confirmAction: (key, code) {
      //       //发送验证码
      //       _requestSendSMS(key, code);
      //     },
      //   ),
      // );
    }
  }

  /// 请求接口，发送验证码
  void _requestSendSMS(String? key, String? code) async {
    // //获取到数据
    // SmartDialog.showLoading();
    // var result = await authRepository.sendPhoneSMS('update_phone', phone, key, code);
    // SmartDialog.dismiss(status: SmartStatus.loading);
    //
    // //处理数据
    // if (result.isSuccess) {
    //   //成功之后开始倒计时
    //   _startCountDown();
    // } else {
    //   String? errorMessage = result.errorMsg;
    //   SmartDialog.showToast(errorMessage ?? '未知错误'.tr);
    // }
  }

  // =========================== 倒计时控制 ===========================

  final int _initialTime = 60; // 初始倒计时时间（秒）
  int countdownTime = 0; // 当前倒计时剩余时间（秒）
  Timer? countdownTimer;
  bool isCounting = false;

  /// 开启倒计时
  void _startCountDown() {
    countdownTime = _initialTime;
    isCounting = true;
    update();

    //每秒的倒计时
    countdownTimer = Timer.periodic(const Duration(seconds: 1), (timer) {
      if (countdownTime > 0) {
        countdownTime--;
      } else {
        isCounting = false;
        countdownTimer?.cancel(); // 取消计时器
      }
      update();
    });
  }

  // =========================== 焦点控制 ===========================

  FocusNode? _phoneFocusNode;
  FocusNode? _codeFocusNode;

  void _onPhoneFocusChange() {
    if (_phoneFocusNode?.hasFocus == true) {
      mobilePhoneErrorText = null;
      update();
    }
  }

  void _onCodeFocusChange() {
    if (_codeFocusNode?.hasFocus == true) {
      codeErrorText = null;
      update();
    }
  }


  @override
  void onInit() {
    super.onInit();
    _phoneFocusNode = state.formData['phone']!['focusNode'];
    _codeFocusNode = state.formData['code']!['focusNode'];
  }

  @override
  void onReady() {
    super.onReady();
    _phoneFocusNode?.addListener(_onPhoneFocusChange);
    _codeFocusNode?.addListener(_onCodeFocusChange);
  }

  @override
  void onClose() {
    super.onClose();
    _phoneFocusNode?.removeListener(_onPhoneFocusChange);
    _codeFocusNode?.removeListener(_onCodeFocusChange);
    _phoneFocusNode = null;
    _codeFocusNode = null;

    countdownTimer?.cancel(); // 取消计时器
  }

}
