import 'dart:ffi';

import 'package:flutter/material.dart';
import 'package:flutter_keyboard_visibility/flutter_keyboard_visibility.dart';
import 'package:get/get.dart';
import 'package:plugin_basic/base/base_stateless_page.dart';
import 'package:plugin_basic/utils/ext_get_nav.dart';
import 'package:cs_resources/constants/color_constants.dart';
import 'package:cs_resources/generated/assets.dart';
import 'package:router/path/router_path.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/my_appbar.dart';
import 'package:widgets/my_button.dart';
import 'package:widgets/my_load_image.dart';
import 'package:widgets/my_text_field.dart';
import 'package:widgets/my_text_view.dart';
import 'package:widgets/utils/dark_theme_util.dart';
import 'change_mobile_controller.dart';
import 'change_mobile_state.dart';

class ChangeMobilePage extends BaseStatelessPage<ChangeMobileController> {
  ChangeMobilePage({super.key});

  late ChangeMobileState state;

  @override
  ChangeMobileController createRawController() {
    return ChangeMobileController();
  }

  //启动当前页面
  static void startInstance() {
    return Get.start(RouterPath.CHANGEMOBILE);
  }

  @override
  void initState() {
    state = controller.state;
  }

  @override
  Widget buildWidget(BuildContext context) {
    return Scaffold(
        appBar: MyAppBar.appBar(context, "修改手机号"),
        body: SafeArea(
          bottom: true,
          top: false,
          child: SizedBox(
            width: double.infinity,
            child: SingleChildScrollView(
              scrollDirection: Axis.vertical,
              physics: const BouncingScrollPhysics(),
              child: autoCtlGetBuilder(builder: (controller) {
                return Column(
                  mainAxisSize: MainAxisSize.max,
                  crossAxisAlignment: CrossAxisAlignment.center,
                  children: [
                    //电话号码
                    _buildInputLayout(
                      "phone",
                      Assets.cptAuthLoginPhoneIcon,
                      leftIconWidth: 13.5,
                      leftIconHeight: 16,
                      marginTop: 20,
                      textInputType: TextInputType.phone,
                      textInputAction: TextInputAction.next,
                      errorText: controller.mobilePhoneErrorText,
                      onSubmit: (formKey, value) {
                        state.formData[formKey]!['focusNode'].unfocus();
                        FocusScope.of(context).requestFocus(state.formData['code']!['focusNode']);
                      },
                    ),

                    //验证码
                    _buildInputLayout(
                      "code",
                      Assets.cptAuthLoginVerifyIcon,
                      leftIconWidth: 13.5,
                      leftIconHeight: 15,
                      marginTop: 10,
                      paddingRight: 15,
                      textInputAction: TextInputAction.next,
                      errorText: controller.codeErrorText,
                      showRightIcon: true,
                      rightWidget: MyTextView(
                        controller.isCounting ? controller.countdownTime.toString() + " s" : '获取验证码'.tr,
                        textAlign: TextAlign.center,
                        textColor: controller.isCounting ? ColorConstants.gray99 : ColorConstants.appBlue,
                        fontSize: 14,
                        paddingRight: 3,
                        isFontMedium: true,
                        onClick: controller.isCounting ? null : () => controller.showVerifyCodedDialog(),
                      ).paddingOnly(top: 15, bottom: 15),
                      onSubmit: (formKey, value) {
                        state.formData[formKey]!['focusNode'].unfocus();
                        controller.doChangePhone();
                      },
                    ),

                    //登录按钮
                    MyButton(
                      text: "提交".tr,
                      textColor: ColorConstants.whitefe,
                      fontSize: 16,
                      fontWeight: FontWeight.w700,
                      backgroundColor: ColorConstants.appBlue,
                      minHeight: 50,
                      radius: 5,
                      onPressed: () => controller.doChangePhone(),
                    ).marginOnly(left: 20, right: 20, top: 28, bottom: 43),
                  ],
                );
              }),
            ),
          ),
        ));
  }

  /// 手机号码与验证码的输入框
  _buildInputLayout(
    String key,
    String leftIconRes, {
    double leftIconWidth = 0,
    double leftIconHeight = 0,
    double marginTop = 23,
    double paddingRight = 18,
    bool? showRightIcon = false, //是否展示右侧的布局
    Widget? rightWidget, //右侧的布局
    TextInputType textInputType = TextInputType.text,
    String? errorText,
    TextInputAction textInputAction = TextInputAction.done,
    Function? onSubmit,
  }) {
    return IgnoreKeyboardDismiss(
      child: MyTextField(
        key,
        state.formData[key]!['value'],
        hintText: state.formData[key]!['hintText'],
        hintStyle: const TextStyle(
          fontSize: 14.0,
          fontWeight: FontWeight.w500,
        ),
        controller: state.formData[key]!['controller'],
        focusNode: state.formData[key]!['focusNode'],
        margin: EdgeInsets.only(left: 20, right: 20, top: marginTop),
        showDivider: false,
        fillBackgroundColor: DarkThemeUtil.multiColors(ColorConstants.white, darkColor: ColorConstants.darkBlackItem),
        fillCornerRadius: 5,
        padding: EdgeInsets.only(left: 16, right: paddingRight, top: 2.5, bottom: 2.5),
        height: 50,
        style: TextStyle(
          color: DarkThemeUtil.multiColors(ColorConstants.tabTextBlack, darkColor: ColorConstants.white),
          fontSize: 14.0,
          fontWeight: FontWeight.w500,
        ),
        inputType: textInputType,
        textInputAction: textInputAction,
        onSubmit: onSubmit,
        cursorColor: ColorConstants.tabTextBlack,
        obscureText: state.formData[key]!['obsecure'],
        errorText: errorText,
        showLeftIcon: true,
        showRightIcon: showRightIcon,
        rightWidget: rightWidget,
        leftWidget: Row(
          children: [
            MyAssetImage(leftIconRes, width: leftIconWidth, height: leftIconHeight),
            const Spacer(),
            Container(
              color: ColorConstants.graye5,
              width: 1,
              height: 15,
            )
          ],
        ).constrained(width: 30),
      ),
    );
  }
}
